==> segment-wrapper-2.3.0-beta.0.tgz: package/lib/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import getAdobeMCVisitorId from './getAdobeMCVisitorID';
export default {
  identify: function identify() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return new Promise(function (resolve, reject) {
      var _window$analytics;

      (_window$analytics = window.analytics).identify.apply(_window$analytics, args);

      resolve();
    });
  },
  reset: function reset() {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    return new Promise(function (resolve, reject) {
      var _window$analytics2;

      (_window$analytics2 = window.analytics).reset.apply(_window$analytics2, args);

      resolve();
    });
  },
  track: function track() {
    for (var _len3 = arguments.length, args = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
      args[_key3] = arguments[_key3];
    }

    return new Promise(function (resolve, reject) {
      window.analytics.ready(
      /*#__PURE__*/
      _asyncToGenerator(
      /*#__PURE__*/
      _regeneratorRuntime.mark(function _callee() {
        var event, properties, _args$, trackingOptions, fn, options, mcvid;

        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                event = args[0], properties = args[1], _args$ = args[2], trackingOptions = _args$ === void 0 ? {} : _args$, fn = args[3];
                options = _objectSpread({}, trackingOptions, {
                  traits: _objectSpread({}, trackingOptions.traits, {
                    anonymousId: window.analytics.user().anonymousId(),
                    userId: window.analytics.user().id()
                  })
                });

                if (!(window && window.Visitor)) {
                  _context.next = 7;
                  break;
                }

                _context.next = 5;
                return getAdobeMCVisitorId();

              case 5:
                mcvid = _context.sent;
                options.integrations = _objectSpread({}, trackingOptions.integrations, {
                  'Adobe Analytics': {
                    marketingCloudVisitorId: mcvid
                  }
                });

              case 7:
                window.analytics.track(event, properties, options, fn);
                resolve();

              case 9:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      })));
    });
  }
};

==> segment-wrapper-2.6.0-beta.0.tgz: package/lib/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import { getAdobeMCVisitorID } from './adobeRepository';
export default {
  identify: function identify() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return new Promise(function (resolve, reject) {
      var _window$analytics;

      (_window$analytics = window.analytics).identify.apply(_window$analytics, args);

      resolve();
    });
  },
  reset: function reset() {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    return new Promise(function (resolve, reject) {
      var _window$analytics2;

      (_window$analytics2 = window.analytics).reset.apply(_window$analytics2, args);

      resolve();
    });
  },
  track: function track() {
    for (var _len3 = arguments.length, args = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
      args[_key3] = arguments[_key3];
    }

    return new Promise(function (resolve, reject) {
      window.analytics.ready(
      /*#__PURE__*/
      _asyncToGenerator(
      /*#__PURE__*/
      _regeneratorRuntime.mark(function _callee() {
        var event, properties, _args$, trackingOptions, fn, options, mcvid;

        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                event = args[0], properties = args[1], _args$ = args[2], trackingOptions = _args$ === void 0 ? {} : _args$, fn = args[3];
                options = _objectSpread({}, trackingOptions, {
                  traits: _objectSpread({}, trackingOptions.traits, {
                    anonymousId: window.analytics.user().anonymousId(),
                    userId: window.analytics.user().id()
                  })
                });

                if (!(window && window.Visitor)) {
                  _context.next = 8;
                  break;
                }

                _context.next = 5;
                return getAdobeMCVisitorID();

              case 5:
                mcvid = _context.sent;
                properties.marketingCloudVisitorId = mcvid;
                options.integrations = _objectSpread({}, trackingOptions.integrations, {
                  'Adobe Analytics': {
                    marketingCloudVisitorId: mcvid
                  }
                });

              case 8:
                window.analytics.track(event, properties, options, fn);
                resolve();

              case 10:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      })));
    });
  }
};
